Documentation
¶
Overview ¶
Package caddycbrotli provides provides support for the Brotli compression format using a fast and efficient implementation written in C.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Br ¶
type Br struct {
// Quality controls the compression-speed vs compression-density trade-offs.
// The higher the quality, the slower the compression. Range is 0 to 11. Defaults to 6.
Quality *int `json:"quality,omitempty"`
// LGWin is the base 2 logarithm of the sliding window size.
// Range is 10 to 24. 0 indicates automatic configuration based on Quality.
LGWin int `json:"lgwin,omitempty"`
}
Br can create Brotli encoders.
func (Br) AcceptEncoding ¶
AcceptEncoding returns the name of the encoding as used in the Accept-Encoding request headers.
func (Br) CaddyModule ¶
func (Br) CaddyModule() caddy.ModuleInfo
CaddyModule returns the Caddy module information.
func (Br) NewEncoder ¶
NewEncoder returns a new Brotli writer.
func (*Br) UnmarshalCaddyfile ¶
UnmarshalCaddyfile sets up the handler from Caddyfile tokens.
Click to show internal directories.
Click to hide internal directories.